{********************************************************}
{                                                        }
{    SetYear                              version 1.1    }
{                    for MS-DOS, PC-DOS and OS/2 WARP    }
{                                                        }
{    Sets year without value changes of month and day    }
{                                                        }
{    THIS CODE AND INFORMATION IS PROVIDED "AS IS"       }
{    WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED      }
{    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE        }
{    IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR        }
{    FITNESS FOR A PARTICULAR PURPOSE.                   }
{                                                        }
{    Copyright (c) Sergey S. Tkachenko, 2000             }
{                                                        }
{    e-mail: tkachenko@360.com.ua                        }
{    Web:    www.4thfebruary.tk                          }
{                                                        }
{  Used Compilers:                                       }
{    MS-DOS, PC-DOS: Turbo Pascal 7.1                    }
{    OS/2 WARP: Virtual Pascal 1.0                       }
{                                                        }
{  History:                                              }
{    January 3, 2000: First release                      }
{    January 5, 2000: Cosmetic fixes                     }
{    December 7, 2000: OS/2 WARP Version                 }
{                                                        }
{********************************************************}

program SetYear;

{.$DEFINE WARP}

uses Crt, WinDos{$IFDEF WARP}, Use32{$ENDIF};

const
  { date of last version }
  DATE = ' 5 Jan 2000';

  { error constants }
  ERROR_UNKNOWN = 0;
  ERROR_INVALID_YEAR = (-1);
  ERROR_YEAR_OUT_OF_RANGE = (-2);

var
  { global variables }
  dwYear, dwMonth, dwDay, dwDayOfWeek: Word;
  NewYear, Code: Integer;
  OldTextAttr: Byte;

{ auxiliary functions }

function DayName(const DayOfWeek: Word): string;
begin
  case DayOfWeek of
    0: DayName := 'Sunday';
    1: DayName := 'Monday';
    2: DayName := 'Tuesday';
    3: DayName := 'Wednesday';
    4: DayName := 'Thursday';
    5: DayName := 'Friday';
    6: DayName := 'Saturday';
  else
    DayName := '(error)';
  end;
end;

function MonthName(Month: Word): string;
begin
  case Month of
     1: MonthName := 'January';
     2: MonthName := 'February';
     3: MonthName := 'March';
     4: MonthName := 'April';
     5: MonthName := 'May';
     6: MonthName := 'June';
     7: MonthName := 'Jule';
     8: MonthName := 'August';
     9: MonthName := 'September';
    10: MonthName := 'October';
    11: MonthName := 'November';
    12: MonthName := 'December';
  else
    MonthName := '(error)';
  end;
end;

{ main procedures }

procedure ShowAbout;
begin
  TextAttr := Brown + 16*Black;
  Write('');
  TextAttr := White + 16*Brown;
  Write(' SetYear');
  TextAttr := Yellow + 16*Brown;
  Write(' version 1.01    ');
  TextAttr := Black + 16*Brown;
  Write(Date);
  TextAttr := Yellow + 16*Brown;
  Write('    Copyright (c) Sergey S. Tkachenko, 2000 ');
  TextAttr := Black + 16*Brown;
  Write('');
  TextAttr := Black + 16*Brown;
{$ifdef WARP}
  Write(' OS/2 WARP Edition                                           www.4thfebruary.tk ');
{$else}
  Write(' DOS Edition                                                 www.4thfebruary.tk ');
{$endif}
  TextAttr := Brown + 16*Black;
  Write('');
  TextAttr := Brown + 16*Black;
  WriteLn(' Sets year without value changes of month and day                                ');
end;

procedure ShowError(ErrorCode: Integer);
begin
  ShowAbout;
  TextColor(LightRed);
  case ErrorCode of
    ERROR_UNKNOWN:
      begin
        TextAttr := White + 16*Black;
        Write(' Usage: ');
        TextAttr := LightGray + 16*Black;
        Write('setyear [YEAR]', #13#10);
        TextAttr := DarkGray + 16*Black;
        WriteLn('        where [YEAR] is a correct year from 4 numbers up to 2099', #13#10);
        TextAttr := White + 16*Black;
        Write(' Example: ');
        TextAttr := LightGray + 16*Black;
        Write('setyear 2000', #13#10);
        WriteLn;
        WriteLn(' Current date: ', DayName(dwDayOfWeek), ', ', MonthName(dwMonth), ' ', dwDay, ', ', dwYear);
        WriteLn;
      end;
    ERROR_INVALID_YEAR:
      WriteLn(' Error: Value ''', ParamStr(1), ''' is not a valid year.', #13#10);
    ERROR_YEAR_OUT_OF_RANGE:
      WriteLn(' Error: Value ''', ParamStr(1), ''' is out of range.', #13#10);
  end;
end;

{ main program block }

begin
  { save current color settings }
  OldTextAttr := TextAttr;
  { getting current date }
  GetDate(dwYear, dwMonth, dwDay, dwDayOfWeek);
  { checking parameters }
  if ParamCount = 0 then
    ShowError(ERROR_UNKNOWN) else
    begin
      { attempt getting parameter }
      Val(ParamStr(1), NewYear, Code);
      if (Code <> 0) then
        ShowError(ERROR_INVALID_YEAR) else
        begin
          { checking year range }
          if (NewYear < 2000) or (NewYear > 2099) then
            ShowError(ERROR_YEAR_OUT_OF_RANGE) else
            begin
              ShowAbout;
              { attempt to set new date }
              SetDate(NewYear, dwMonth, dwDay);
              TextColor(LightGray);
              { get current date }
              GetDate(dwYear, dwMonth, dwDay, dwDayOfWeek);
              WriteLn(' Sets new date: ', DayName(dwDayOfWeek), ', ', MonthName(dwMonth), ' ', dwDay, ', ', NewYear, #13#10);
            end;
        end;
    end;
  { restore old color settings }
  TextAttr := OldTextAttr;
end.
